@@ -6,9 +6,9 @@ Type annotations for databrew service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_databrew.literals import CompressionFormatType
+    from mypy_boto3_databrew.literals import AnalyticsModeType
 
-    data: CompressionFormatType = "BROTLI"
+    data: AnalyticsModeType = "DISABLE"
     ```
 """
 import sys
@@ -20,6 +20,7 @@ else:
 
 
 __all__ = (
+    "AnalyticsModeType",
     "CompressionFormatType",
     "DatabaseOutputModeType",
     "EncryptionModeType",
@@ -32,6 +33,7 @@ __all__ = (
     "ListProjectsPaginatorName",
     "ListRecipeVersionsPaginatorName",
     "ListRecipesPaginatorName",
+    "ListRulesetsPaginatorName",
     "ListSchedulesPaginatorName",
     "LogSubscriptionType",
     "OrderType",
@@ -42,11 +44,15 @@ __all__ = (
     "SampleTypeType",
     "SessionStatusType",
     "SourceType",
+    "ThresholdTypeType",
+    "ThresholdUnitType",
+    "ValidationModeType",
     "ServiceName",
     "PaginatorName",
 )
 
 
+AnalyticsModeType = Literal["DISABLE", "ENABLE"]
 CompressionFormatType = Literal[
     "BROTLI", "BZIP2", "DEFLATE", "GZIP", "LZ4", "LZO", "SNAPPY", "ZLIB", "ZSTD"
 ]
@@ -63,6 +69,7 @@ ListJobsPaginatorName = Literal["list_jobs"]
 ListProjectsPaginatorName = Literal["list_projects"]
 ListRecipeVersionsPaginatorName = Literal["list_recipe_versions"]
 ListRecipesPaginatorName = Literal["list_recipes"]
+ListRulesetsPaginatorName = Literal["list_rulesets"]
 ListSchedulesPaginatorName = Literal["list_schedules"]
 LogSubscriptionType = Literal["DISABLE", "ENABLE"]
 OrderType = Literal["ASCENDING", "DESCENDING"]
@@ -86,6 +93,11 @@ SessionStatusType = Literal[
     "UPDATING",
 ]
 SourceType = Literal["DATA-CATALOG", "DATABASE", "S3"]
+ThresholdTypeType = Literal[
+    "GREATER_THAN", "GREATER_THAN_OR_EQUAL", "LESS_THAN", "LESS_THAN_OR_EQUAL"
+]
+ThresholdUnitType = Literal["COUNT", "PERCENTAGE"]
+ValidationModeType = Literal["CHECK_ALL"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -99,6 +111,7 @@ ServiceName = Literal[
     "apigatewaymanagementapi",
     "apigatewayv2",
     "appconfig",
+    "appconfigdata",
     "appflow",
     "appintegrations",
     "application-autoscaling",
@@ -167,6 +180,7 @@ ServiceName = Literal[
     "dlm",
     "dms",
     "docdb",
+    "drs",
     "ds",
     "dynamodb",
     "dynamodbstreams",
@@ -273,6 +287,7 @@ ServiceName = Literal[
     "mgh",
     "mgn",
     "migrationhub-config",
+    "migrationhubstrategy",
     "mobile",
     "mq",
     "mturk",
@@ -306,6 +321,7 @@ ServiceName = Literal[
     "redshift",
     "redshift-data",
     "rekognition",
+    "resiliencehub",
     "resource-groups",
     "resourcegroupstaggingapi",
     "robomaker",
@@ -381,5 +397,6 @@ PaginatorName = Literal[
     "list_projects",
     "list_recipe_versions",
     "list_recipes",
+    "list_rulesets",
     "list_schedules",
 ]
