@@ -16,6 +16,7 @@ Usage::
         ListProjectsPaginator,
         ListRecipeVersionsPaginator,
         ListRecipesPaginator,
+        ListRulesetsPaginator,
         ListSchedulesPaginator,
     )
 
@@ -27,6 +28,7 @@ Usage::
     list_projects_paginator: ListProjectsPaginator = client.get_paginator("list_projects")
     list_recipe_versions_paginator: ListRecipeVersionsPaginator = client.get_paginator("list_recipe_versions")
     list_recipes_paginator: ListRecipesPaginator = client.get_paginator("list_recipes")
+    list_rulesets_paginator: ListRulesetsPaginator = client.get_paginator("list_rulesets")
     list_schedules_paginator: ListSchedulesPaginator = client.get_paginator("list_schedules")
     ```
 """
@@ -42,6 +44,7 @@ from .type_defs import (
     ListProjectsResponseTypeDef,
     ListRecipesResponseTypeDef,
     ListRecipeVersionsResponseTypeDef,
+    ListRulesetsResponseTypeDef,
     ListSchedulesResponseTypeDef,
     PaginatorConfigTypeDef,
 )
@@ -53,6 +56,7 @@ __all__ = (
     "ListProjectsPaginator",
     "ListRecipeVersionsPaginator",
     "ListRecipesPaginator",
+    "ListRulesetsPaginator",
     "ListSchedulesPaginator",
 )
 
@@ -69,7 +73,7 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class ListDatasetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
     """
 
@@ -77,14 +81,14 @@ class ListDatasetsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListDatasetsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListDatasets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listdatasetspaginator)
         """
 
 
 class ListJobRunsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
     """
 
@@ -92,14 +96,14 @@ class ListJobRunsPaginator(Boto3Paginator):
         self, *, Name: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobRunsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobRuns.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobrunspaginator)
         """
 
 
 class ListJobsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
     """
 
@@ -111,14 +115,14 @@ class ListJobsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListJobsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListJobs.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listjobspaginator)
         """
 
 
 class ListProjectsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
     """
 
@@ -126,14 +130,14 @@ class ListProjectsPaginator(Boto3Paginator):
         self, *, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListProjectsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListProjects.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listprojectspaginator)
         """
 
 
 class ListRecipeVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
     """
 
@@ -141,14 +145,14 @@ class ListRecipeVersionsPaginator(Boto3Paginator):
         self, *, Name: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRecipeVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipeVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipeversionspaginator)
         """
 
 
 class ListRecipesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
     """
 
@@ -156,14 +160,29 @@ class ListRecipesPaginator(Boto3Paginator):
         self, *, RecipeVersion: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListRecipesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRecipes.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrecipespaginator)
         """
 
 
+class ListRulesetsPaginator(Boto3Paginator):
+    """
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRulesets)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrulesetspaginator)
+    """
+
+    def paginate(
+        self, *, TargetArn: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
+    ) -> _PageIterator[ListRulesetsResponseTypeDef]:
+        """
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListRulesets.paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listrulesetspaginator)
+        """
+
+
 class ListSchedulesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
     """
 
@@ -171,6 +190,6 @@ class ListSchedulesPaginator(Boto3Paginator):
         self, *, JobName: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListSchedulesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.9/reference/services/databrew.html#GlueDataBrew.Paginator.ListSchedules.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_databrew/paginators.html#listschedulespaginator)
         """
