@@ -6,9 +6,9 @@ Type annotations for databrew service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_databrew.type_defs import BatchDeleteRecipeVersionRequestRequestTypeDef
+    from mypy_boto3_databrew.type_defs import AllowedStatisticsTypeDef
 
-    data: BatchDeleteRecipeVersionRequestRequestTypeDef = {...}
+    data: AllowedStatisticsTypeDef = {...}
     ```
 """
 import sys
@@ -16,6 +16,7 @@ from datetime import datetime
 from typing import Dict, List, Mapping, Sequence
 
 from .literals import (
+    AnalyticsModeType,
     CompressionFormatType,
     EncryptionModeType,
     InputFormatType,
@@ -29,6 +30,8 @@ from .literals import (
     SampleTypeType,
     SessionStatusType,
     SourceType,
+    ThresholdTypeType,
+    ThresholdUnitType,
 )
 
 if sys.version_info >= (3, 9):
@@ -42,6 +45,7 @@ else:
 
 
 __all__ = (
+    "AllowedStatisticsTypeDef",
     "BatchDeleteRecipeVersionRequestRequestTypeDef",
     "BatchDeleteRecipeVersionResponseTypeDef",
     "ColumnSelectorTypeDef",
@@ -57,6 +61,8 @@ __all__ = (
     "CreateRecipeJobResponseTypeDef",
     "CreateRecipeRequestRequestTypeDef",
     "CreateRecipeResponseTypeDef",
+    "CreateRulesetRequestRequestTypeDef",
+    "CreateRulesetResponseTypeDef",
     "CreateScheduleRequestRequestTypeDef",
     "CreateScheduleResponseTypeDef",
     "CsvOptionsTypeDef",
@@ -77,6 +83,8 @@ __all__ = (
     "DeleteProjectResponseTypeDef",
     "DeleteRecipeVersionRequestRequestTypeDef",
     "DeleteRecipeVersionResponseTypeDef",
+    "DeleteRulesetRequestRequestTypeDef",
+    "DeleteRulesetResponseTypeDef",
     "DeleteScheduleRequestRequestTypeDef",
     "DeleteScheduleResponseTypeDef",
     "DescribeDatasetRequestRequestTypeDef",
@@ -89,8 +97,11 @@ __all__ = (
     "DescribeProjectResponseTypeDef",
     "DescribeRecipeRequestRequestTypeDef",
     "DescribeRecipeResponseTypeDef",
+    "DescribeRulesetRequestRequestTypeDef",
+    "DescribeRulesetResponseTypeDef",
     "DescribeScheduleRequestRequestTypeDef",
     "DescribeScheduleResponseTypeDef",
+    "EntityDetectorConfigurationTypeDef",
     "ExcelOptionsTypeDef",
     "FilesLimitTypeDef",
     "FilterExpressionTypeDef",
@@ -112,10 +123,13 @@ __all__ = (
     "ListRecipeVersionsResponseTypeDef",
     "ListRecipesRequestRequestTypeDef",
     "ListRecipesResponseTypeDef",
+    "ListRulesetsRequestRequestTypeDef",
+    "ListRulesetsResponseTypeDef",
     "ListSchedulesRequestRequestTypeDef",
     "ListSchedulesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "MetadataTypeDef",
     "OutputFormatOptionsTypeDef",
     "OutputTypeDef",
     "PaginatorConfigTypeDef",
@@ -130,6 +144,8 @@ __all__ = (
     "RecipeTypeDef",
     "RecipeVersionErrorDetailTypeDef",
     "ResponseMetadataTypeDef",
+    "RuleTypeDef",
+    "RulesetItemTypeDef",
     "S3LocationTypeDef",
     "S3TableOutputOptionsTypeDef",
     "SampleTypeDef",
@@ -145,6 +161,7 @@ __all__ = (
     "StopJobRunRequestRequestTypeDef",
     "StopJobRunResponseTypeDef",
     "TagResourceRequestRequestTypeDef",
+    "ThresholdTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateDatasetRequestRequestTypeDef",
     "UpdateDatasetResponseTypeDef",
@@ -156,11 +173,21 @@ __all__ = (
     "UpdateRecipeJobResponseTypeDef",
     "UpdateRecipeRequestRequestTypeDef",
     "UpdateRecipeResponseTypeDef",
+    "UpdateRulesetRequestRequestTypeDef",
+    "UpdateRulesetResponseTypeDef",
     "UpdateScheduleRequestRequestTypeDef",
     "UpdateScheduleResponseTypeDef",
+    "ValidationConfigurationTypeDef",
     "ViewFrameTypeDef",
 )
 
+AllowedStatisticsTypeDef = TypedDict(
+    "AllowedStatisticsTypeDef",
+    {
+        "Statistics": Sequence[str],
+    },
+)
+
 BatchDeleteRecipeVersionRequestRequestTypeDef = TypedDict(
     "BatchDeleteRecipeVersionRequestRequestTypeDef",
     {
@@ -281,6 +308,7 @@ _OptionalCreateProfileJobRequestRequestTypeDef = TypedDict(
         "MaxCapacity": int,
         "MaxRetries": int,
         "Configuration": "ProfileConfigurationTypeDef",
+        "ValidationConfigurations": Sequence["ValidationConfigurationTypeDef"],
         "Tags": Mapping[str, str],
         "Timeout": int,
         "JobSample": "JobSampleTypeDef",
@@ -409,6 +437,38 @@ CreateRecipeResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateRulesetRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateRulesetRequestRequestTypeDef",
+    {
+        "Name": str,
+        "TargetArn": str,
+        "Rules": Sequence["RuleTypeDef"],
+    },
+)
+_OptionalCreateRulesetRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateRulesetRequestRequestTypeDef",
+    {
+        "Description": str,
+        "Tags": Mapping[str, str],
+    },
+    total=False,
+)
+
+
+class CreateRulesetRequestRequestTypeDef(
+    _RequiredCreateRulesetRequestRequestTypeDef, _OptionalCreateRulesetRequestRequestTypeDef
+):
+    pass
+
+
+CreateRulesetResponseTypeDef = TypedDict(
+    "CreateRulesetResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateScheduleRequestRequestTypeDef = TypedDict(
     "_RequiredCreateScheduleRequestRequestTypeDef",
     {
@@ -509,13 +569,14 @@ _RequiredDatabaseInputDefinitionTypeDef = TypedDict(
     "_RequiredDatabaseInputDefinitionTypeDef",
     {
         "GlueConnectionName": str,
-        "DatabaseTableName": str,
     },
 )
 _OptionalDatabaseInputDefinitionTypeDef = TypedDict(
     "_OptionalDatabaseInputDefinitionTypeDef",
     {
+        "DatabaseTableName": str,
         "TempDirectory": "S3LocationTypeDef",
+        "QueryString": str,
     },
     total=False,
 )
@@ -702,6 +763,21 @@ DeleteRecipeVersionResponseTypeDef = TypedDict(
     },
 )
 
+DeleteRulesetRequestRequestTypeDef = TypedDict(
+    "DeleteRulesetRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+DeleteRulesetResponseTypeDef = TypedDict(
+    "DeleteRulesetResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DeleteScheduleRequestRequestTypeDef = TypedDict(
     "DeleteScheduleRequestRequestTypeDef",
     {
@@ -770,6 +846,7 @@ DescribeJobResponseTypeDef = TypedDict(
         "DatabaseOutputs": List["DatabaseOutputTypeDef"],
         "ProjectName": str,
         "ProfileConfiguration": "ProfileConfigurationTypeDef",
+        "ValidationConfigurations": List["ValidationConfigurationTypeDef"],
         "RecipeReference": "RecipeReferenceTypeDef",
         "ResourceArn": str,
         "RoleArn": str,
@@ -798,6 +875,7 @@ DescribeJobRunResponseTypeDef = TypedDict(
         "ExecutionTime": int,
         "JobName": str,
         "ProfileConfiguration": "ProfileConfigurationTypeDef",
+        "ValidationConfigurations": List["ValidationConfigurationTypeDef"],
         "RunId": str,
         "State": JobRunStateType,
         "LogSubscription": LogSubscriptionType,
@@ -882,6 +960,30 @@ DescribeRecipeResponseTypeDef = TypedDict(
     },
 )
 
+DescribeRulesetRequestRequestTypeDef = TypedDict(
+    "DescribeRulesetRequestRequestTypeDef",
+    {
+        "Name": str,
+    },
+)
+
+DescribeRulesetResponseTypeDef = TypedDict(
+    "DescribeRulesetResponseTypeDef",
+    {
+        "Name": str,
+        "Description": str,
+        "TargetArn": str,
+        "Rules": List["RuleTypeDef"],
+        "CreateDate": datetime,
+        "CreatedBy": str,
+        "LastModifiedBy": str,
+        "LastModifiedDate": datetime,
+        "ResourceArn": str,
+        "Tags": Dict[str, str],
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeScheduleRequestRequestTypeDef = TypedDict(
     "DescribeScheduleRequestRequestTypeDef",
     {
@@ -905,6 +1007,27 @@ DescribeScheduleResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredEntityDetectorConfigurationTypeDef = TypedDict(
+    "_RequiredEntityDetectorConfigurationTypeDef",
+    {
+        "EntityTypes": Sequence[str],
+    },
+)
+_OptionalEntityDetectorConfigurationTypeDef = TypedDict(
+    "_OptionalEntityDetectorConfigurationTypeDef",
+    {
+        "AllowedStatistics": Sequence["AllowedStatisticsTypeDef"],
+    },
+    total=False,
+)
+
+
+class EntityDetectorConfigurationTypeDef(
+    _RequiredEntityDetectorConfigurationTypeDef, _OptionalEntityDetectorConfigurationTypeDef
+):
+    pass
+
+
 ExcelOptionsTypeDef = TypedDict(
     "ExcelOptionsTypeDef",
     {
@@ -959,6 +1082,7 @@ InputTypeDef = TypedDict(
         "S3InputDefinition": "S3LocationTypeDef",
         "DataCatalogInputDefinition": "DataCatalogInputDefinitionTypeDef",
         "DatabaseInputDefinition": "DatabaseInputDefinitionTypeDef",
+        "Metadata": "MetadataTypeDef",
     },
     total=False,
 )
@@ -983,6 +1107,7 @@ JobRunTypeDef = TypedDict(
         "StartedBy": str,
         "StartedOn": datetime,
         "JobSample": "JobSampleTypeDef",
+        "ValidationConfigurations": List["ValidationConfigurationTypeDef"],
     },
     total=False,
 )
@@ -1027,6 +1152,7 @@ _OptionalJobTypeDef = TypedDict(
         "Timeout": int,
         "Tags": Dict[str, str],
         "JobSample": "JobSampleTypeDef",
+        "ValidationConfigurations": List["ValidationConfigurationTypeDef"],
     },
     total=False,
 )
@@ -1182,6 +1308,25 @@ ListRecipesResponseTypeDef = TypedDict(
     },
 )
 
+ListRulesetsRequestRequestTypeDef = TypedDict(
+    "ListRulesetsRequestRequestTypeDef",
+    {
+        "TargetArn": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListRulesetsResponseTypeDef = TypedDict(
+    "ListRulesetsResponseTypeDef",
+    {
+        "Rulesets": List["RulesetItemTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListSchedulesRequestRequestTypeDef = TypedDict(
     "ListSchedulesRequestRequestTypeDef",
     {
@@ -1216,6 +1361,14 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+MetadataTypeDef = TypedDict(
+    "MetadataTypeDef",
+    {
+        "SourceArn": str,
+    },
+    total=False,
+)
+
 OutputFormatOptionsTypeDef = TypedDict(
     "OutputFormatOptionsTypeDef",
     {
@@ -1273,6 +1426,7 @@ ProfileConfigurationTypeDef = TypedDict(
         "DatasetStatisticsConfiguration": "StatisticsConfigurationTypeDef",
         "ProfileColumns": Sequence["ColumnSelectorTypeDef"],
         "ColumnStatisticsConfigurations": Sequence["ColumnStatisticsConfigurationTypeDef"],
+        "EntityDetectorConfiguration": "EntityDetectorConfigurationTypeDef",
     },
     total=False,
 )
@@ -1445,6 +1599,57 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
+_RequiredRuleTypeDef = TypedDict(
+    "_RequiredRuleTypeDef",
+    {
+        "Name": str,
+        "CheckExpression": str,
+    },
+)
+_OptionalRuleTypeDef = TypedDict(
+    "_OptionalRuleTypeDef",
+    {
+        "Disabled": bool,
+        "SubstitutionMap": Mapping[str, str],
+        "Threshold": "ThresholdTypeDef",
+        "ColumnSelectors": Sequence["ColumnSelectorTypeDef"],
+    },
+    total=False,
+)
+
+
+class RuleTypeDef(_RequiredRuleTypeDef, _OptionalRuleTypeDef):
+    pass
+
+
+_RequiredRulesetItemTypeDef = TypedDict(
+    "_RequiredRulesetItemTypeDef",
+    {
+        "Name": str,
+        "TargetArn": str,
+    },
+)
+_OptionalRulesetItemTypeDef = TypedDict(
+    "_OptionalRulesetItemTypeDef",
+    {
+        "AccountId": str,
+        "CreatedBy": str,
+        "CreateDate": datetime,
+        "Description": str,
+        "LastModifiedBy": str,
+        "LastModifiedDate": datetime,
+        "ResourceArn": str,
+        "RuleCount": int,
+        "Tags": Dict[str, str],
+    },
+    total=False,
+)
+
+
+class RulesetItemTypeDef(_RequiredRulesetItemTypeDef, _OptionalRulesetItemTypeDef):
+    pass
+
+
 _RequiredS3LocationTypeDef = TypedDict(
     "_RequiredS3LocationTypeDef",
     {
@@ -1640,6 +1845,26 @@ TagResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
+_RequiredThresholdTypeDef = TypedDict(
+    "_RequiredThresholdTypeDef",
+    {
+        "Value": float,
+    },
+)
+_OptionalThresholdTypeDef = TypedDict(
+    "_OptionalThresholdTypeDef",
+    {
+        "Type": ThresholdTypeType,
+        "Unit": ThresholdUnitType,
+    },
+    total=False,
+)
+
+
+class ThresholdTypeDef(_RequiredThresholdTypeDef, _OptionalThresholdTypeDef):
+    pass
+
+
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -1697,6 +1922,7 @@ _OptionalUpdateProfileJobRequestRequestTypeDef = TypedDict(
         "LogSubscription": LogSubscriptionType,
         "MaxCapacity": int,
         "MaxRetries": int,
+        "ValidationConfigurations": Sequence["ValidationConfigurationTypeDef"],
         "Timeout": int,
         "JobSample": "JobSampleTypeDef",
     },
@@ -1817,6 +2043,36 @@ UpdateRecipeResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateRulesetRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateRulesetRequestRequestTypeDef",
+    {
+        "Name": str,
+        "Rules": Sequence["RuleTypeDef"],
+    },
+)
+_OptionalUpdateRulesetRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateRulesetRequestRequestTypeDef",
+    {
+        "Description": str,
+    },
+    total=False,
+)
+
+
+class UpdateRulesetRequestRequestTypeDef(
+    _RequiredUpdateRulesetRequestRequestTypeDef, _OptionalUpdateRulesetRequestRequestTypeDef
+):
+    pass
+
+
+UpdateRulesetResponseTypeDef = TypedDict(
+    "UpdateRulesetResponseTypeDef",
+    {
+        "Name": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateScheduleRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateScheduleRequestRequestTypeDef",
     {
@@ -1847,6 +2103,27 @@ UpdateScheduleResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredValidationConfigurationTypeDef = TypedDict(
+    "_RequiredValidationConfigurationTypeDef",
+    {
+        "RulesetArn": str,
+    },
+)
+_OptionalValidationConfigurationTypeDef = TypedDict(
+    "_OptionalValidationConfigurationTypeDef",
+    {
+        "ValidationMode": Literal["CHECK_ALL"],
+    },
+    total=False,
+)
+
+
+class ValidationConfigurationTypeDef(
+    _RequiredValidationConfigurationTypeDef, _OptionalValidationConfigurationTypeDef
+):
+    pass
+
+
 _RequiredViewFrameTypeDef = TypedDict(
     "_RequiredViewFrameTypeDef",
     {
@@ -1858,6 +2135,9 @@ _OptionalViewFrameTypeDef = TypedDict(
     {
         "ColumnRange": int,
         "HiddenColumns": Sequence[str],
+        "StartRowIndex": int,
+        "RowRange": int,
+        "Analytics": AnalyticsModeType,
     },
     total=False,
 )
